@@ -20,7 +20,11 @@
 #include "qgis_core.h"
 #include "qgis_sip.h"
 #include <QObject>
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
 #include <QMutex>
+#else
+#include <QRecursiveMutex>
+#endif
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QSqlDatabase>
@@ -55,7 +59,7 @@ class QTimer;
 
 /**
  * \ingroup core
- * Singleton offering an interface to manage the authentication configuration database
+ * \brief Singleton offering an interface to manage the authentication configuration database
  * and to utilize configurations through various authentication method plugins
  *
  * QgsAuthManager should not usually be directly created, but rather accessed through
@@ -269,9 +273,10 @@ class CORE_EXPORT QgsAuthManager : public QObject
     /**
      * Store an authentication config in the database
      * \param mconfig Associated authentication config id
+     * \param overwrite If set to TRUE, pre-existing authentication configurations will be overwritten
      * \returns Whether operation succeeded
      */
-    bool storeAuthenticationConfig( QgsAuthMethodConfig &mconfig SIP_INOUT );
+    bool storeAuthenticationConfig( QgsAuthMethodConfig &mconfig SIP_INOUT, bool overwrite = false );
 
     /**
      * Update an authentication config in the database
@@ -296,6 +301,24 @@ class CORE_EXPORT QgsAuthManager : public QObject
      */
     bool removeAuthenticationConfig( const QString &authcfg );
 
+    /**
+     * Export authentication configurations to an XML file
+     * \param filename The file path to save the XML content to
+     * \param authcfgs The list of configuration IDs to export
+     * \param password A password string to encrypt the XML content
+     * \since QGIS 3.20
+     */
+    bool exportAuthenticationConfigsToXml( const QString &filename, const QStringList &authcfgs, const QString &password = QString() );
+
+    /**
+     * Import authentication configurations from an XML file
+     * \param filename The file path from which the XML content will be read
+     * \param password A password string to decrypt the XML content
+     * \param overwrite If set to TRUE, pre-existing authentication configurations will be overwritten
+     * \since QGIS 3.20
+     */
+    bool importAuthenticationConfigsFromXml( const QString &filename, const QString &password = QString(), bool overwrite = false );
+
     /**
      * Clear all authentication configs from table in database and from provider caches
      * \returns Whether operation succeeded
@@ -752,7 +775,14 @@ class CORE_EXPORT QgsAuthManager : public QObject
      */
     static QgsAuthManager *instance() SIP_SKIP;
 
+
+#ifdef Q_OS_WIN
+  public:
     explicit QgsAuthManager() SIP_SKIP;
+#else
+  protected:
+    explicit QgsAuthManager() SIP_SKIP;
+#endif
 
   private:
 
@@ -862,8 +892,14 @@ class CORE_EXPORT QgsAuthManager : public QObject
     int mScheduledDbEraseRequestWait = 3 ; // in seconds
     bool mScheduledDbEraseRequestEmitted = false;
     int mScheduledDbEraseRequestCount = 0;
-    QMutex *mMutex = nullptr;
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    std::unique_ptr<QMutex> mMutex;
+    std::unique_ptr<QMutex> mMasterPasswordMutex;
+#else
+    std::unique_ptr<QRecursiveMutex> mMutex;
+    std::unique_ptr<QRecursiveMutex> mMasterPasswordMutex;
+#endif
 #ifndef QT_NO_SSL
     // mapping of sha1 digest and cert source and cert
     // appending removes duplicates
