@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.18.1-Zürich"
-#define _QGIS_VERSION "3.18.1-Zürich"
+#define VERSION "3.20.0-Odense"
+#define _QGIS_VERSION "3.20.0-Odense"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3181
+//#define VERSION_INT 3200
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 31801
-#define _QGIS_VERSION_INT 31801
-#define ABISYM(x) x ## 31801
+#define VERSION_INT 32000
+#define _QGIS_VERSION_INT 32000
+#define ABISYM(x) x ## 32000
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Zürich"
+#define RELEASE_NAME "Odense"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,11 +31,13 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.18.1"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.20.0"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
+#if !defined(QSCINTILLA_VERSION_STR)
 #define QSCINTILLA_VERSION_STR "2.12.1"
+#endif
 
 #if defined( __APPLE__ )
 //used by Mac to find system or bundle resources relative to amount of bundling
@@ -44,12 +46,19 @@
 
 #define QT_PLUGINS_DIR "/usr/lib/qt/plugins"
 
+#define PYTHON_VERSION "3.9.5"
+#define PYTHON_VERSION_MAJOR "3"
+#define PYTHON_VERSION_MINOR "9"
+#define PYTHON_VERSION_PATCH "5"
+
 /* #undef USING_NMAKE */
 
-/* #undef USING_NINJA */
+#define USING_NINJA
 
 #define HAVE_GUI
 
+#define HAVE_SPATIALITE
+
 #define HAVE_POSTGRESQL
 
 /* #undef HAVE_ORACLE */
@@ -60,12 +69,15 @@
 
 #define HAVE_SERVER_PYTHON_PLUGINS
 
-/* #undef HAVE_OPENCL */
+#define HAVE_OPENCL
+#define OPENCL_USE_NEW_HEADER
 
 /* #undef ENABLE_MODELTEST */
 
 #define HAVE_3D
 
+#define HAVE_GSL
+
 #define HAVE_GEOREFERENCER
 
 #define USE_THREAD_LOCAL
@@ -80,13 +92,15 @@
 
 #define HAVE_EPT
 
-/* #undef HAVE_PDAL */
-#define PDAL_VERSION ""
-#define PDAL_VERSION_MAJOR_INT 
-#define PDAL_VERSION_MINOR_INT 
-#define PDAL_VERSION_MAJOR ""
-#define PDAL_VERSION_MINOR ""
-#define PDAL_VERSION_MICRO ""
+#define HAVE_PDAL
+#define PDAL_VERSION "2.2.0"
+#define PDAL_VERSION_MAJOR_INT 2
+#define PDAL_VERSION_MINOR_INT 2
+#define PDAL_VERSION_MAJOR "2"
+#define PDAL_VERSION_MINOR "2"
+#define PDAL_VERSION_MICRO "0"
+
+#define ENABLE_TESTS
 
 #endif
 
